@@ -20,10 +20,10 @@ except NameError:
 
 
 __title__ = "vak"
-__summary__ = "a neural network toolbox for animal vocalizations and bioacoustics"
+__summary__ = "A neural network framework for researchers studying acoustic communication"
 __uri__ = "https://github.com/NickleDave/vak"
 
-__version__ = "0.4.1"
+__version__ = "1.0.4"
 
 if base_dir is not None and os.path.exists(os.path.join(base_dir, ".commit")):
     with open(os.path.join(base_dir, ".commit")) as fp:
