@@ -1,8 +1,31 @@
-from .eval import eval
-from .train import train
-from .learncurve import learning_curve
-from .predict import predict
-from .prep import prep
+def eval(toml_path):
+    from .eval import eval
+
+    eval(toml_path=toml_path)
+
+
+def train(toml_path):
+    from .train import train
+
+    train(toml_path=toml_path)
+
+
+def learncurve(toml_path):
+    from .learncurve import learning_curve
+
+    learning_curve(toml_path=toml_path)
+
+
+def predict(toml_path):
+    from .predict import predict
+
+    predict(toml_path=toml_path)
+
+
+def prep(toml_path):
+    from .prep import prep
+
+    prep(toml_path=toml_path)
 
 
 COMMAND_FUNCTION_MAP = {
@@ -10,14 +33,15 @@ COMMAND_FUNCTION_MAP = {
     "train": train,
     "eval": eval,
     "predict": predict,
-    "learncurve": learning_curve,
+    "learncurve": learncurve,
 }
 
+
 CLI_COMMANDS = tuple(COMMAND_FUNCTION_MAP.keys())
 
 
 def cli(command, config_file):
-    """command-line interface
+    """Execute the commands of the command-line interface.
 
     Parameters
     ----------
