@@ -1,9 +1,11 @@
-from datetime import datetime
+import logging
 from pathlib import Path
 
-from .. import config
-from .. import core
-from .. import logging
+from .. import common, config
+from .. import predict as predict_module
+from ..common.logging import config_logging_for_cli, log_version
+
+logger = logging.getLogger(__name__)
 
 
 def predict(toml_path):
@@ -14,13 +16,9 @@ def predict(toml_path):
     ----------
     toml_path : str, Path
         path to a configuration file in TOML format.
-
-    Returns
-    -------
-    None
     """
     toml_path = Path(toml_path)
-    cfg = config.parse.from_toml_path(toml_path)
+    cfg = config.Config.from_toml_path(toml_path)
 
     if cfg.predict is None:
         raise ValueError(
@@ -28,32 +26,38 @@ def predict(toml_path):
         )
 
     # ---- set up logging ----------------------------------------------------------------------------------------------
-    timenow = datetime.now().strftime("%y%m%d_%H%M%S")
-    logger = logging.get_logger(
+    config_logging_for_cli(
         log_dst=cfg.predict.output_dir,
-        caller="predict",
-        timestamp=timenow,
-        logger_name=__name__,
+        log_stem="predict",
+        level="INFO",
+        force=True,
     )
-    logger.info("Logging results to {}".format(cfg.prep.output_dir))
+    log_version(logger)
+    logger.info("Logging results to {}".format(cfg.predict.output_dir))
 
-    model_config_map = config.models.map_from_path(toml_path, cfg.predict.models)
+    if cfg.predict.dataset.path is None:
+        raise ValueError(
+            "No value is specified for 'dataset_path' in this .toml config file."
+            f"To generate a .csv file that represents the dataset, "
+            f"please run the following command:\n'vak prep {toml_path}'"
+        )
 
-    core.predict(
-        csv_path=cfg.predict.csv_path,
+    predict_module.predict(
+        model_config=cfg.predict.model.asdict(),
+        dataset_config=cfg.predict.dataset.asdict(),
+        trainer_config=cfg.predict.trainer.asdict(),
         checkpoint_path=cfg.predict.checkpoint_path,
         labelmap_path=cfg.predict.labelmap_path,
-        model_config_map=model_config_map,
-        window_size=cfg.dataloader.window_size,
         num_workers=cfg.predict.num_workers,
-        spect_key=cfg.spect_params.spect_key,
-        timebins_key=cfg.spect_params.timebins_key,
-        spect_scaler_path=cfg.predict.spect_scaler_path,
-        device=cfg.predict.device,
+        timebins_key=(
+            cfg.prep.spect_params.timebins_key
+            if cfg.prep
+            else common.constants.TIMEBINS_KEY
+        ),
+        frames_standardizer_path=cfg.predict.frames_standardizer_path,
         annot_csv_filename=cfg.predict.annot_csv_filename,
         output_dir=cfg.predict.output_dir,
         min_segment_dur=cfg.predict.min_segment_dur,
         majority_vote=cfg.predict.majority_vote,
         save_net_outputs=cfg.predict.save_net_outputs,
-        logger=logger,
     )
