@@ -1,4 +1,5 @@
 """parses [SPECT_PARAMS] section of config"""
+
 import attr
 from attr import converters, validators
 from attr.validators import instance_of
@@ -70,7 +71,9 @@ class SpectParamsConfig:
         default=None,
     )
     transform_type = attr.ib(
-        validator=validators.optional([instance_of(str), is_valid_transform_type]),
+        validator=validators.optional(
+            [instance_of(str), is_valid_transform_type]
+        ),
         default=None,
     )
     spect_key = attr.ib(validator=instance_of(str), default="s")
