@@ -1,4 +1,5 @@
 import numpy as np
+import torch
 
 
 def levenshtein(source, target):
@@ -65,10 +66,10 @@ def levenshtein(source, target):
 
         d0, d1 = d1, d0
 
-    return d0[-1]
+    return torch.tensor(d0[-1], dtype=torch.int32)
 
 
-def segment_error_rate(y_pred, y_true):
+def character_error_rate(y_pred, y_true):
     """Levenshtein edit distance normalized by length of true sequence.
     Also known as word error distance; here applied to other vocalizations
     in addition to speech.
@@ -84,15 +85,16 @@ def segment_error_rate(y_pred, y_true):
     -------
     Levenshtein distance / len(y_true)
     """
-    if type(y_true) != str or type(y_pred) != str:
+    if not isinstance(y_true, str) or not isinstance(y_pred, str):
         raise TypeError("Both `y_true` and `y_pred` must be of type `str")
 
     # handle divide by zero edge cases
     if len(y_true) == 0 and len(y_pred) == 0:
-        return 0.
+        return 0.0
     elif len(y_true) == 0 and len(y_pred) != 0:
         raise ValueError(
-            f'segment error rate is undefined when length of y_true is zero'
+            "segment error rate is undefined when length of y_true is zero"
         )
 
-    return levenshtein(y_pred, y_true) / len(y_true)
+    rate = levenshtein(y_pred, y_true) / len(y_true)
+    return torch.tensor(rate, dtype=torch.float32)
