@@ -1,4 +1,9 @@
+"""Functional forms of input transforms."""
+
+from __future__ import annotations
+
 import numpy as np
+import numpy.typing as npt
 import torch
 
 __all__ = [
@@ -18,9 +23,9 @@ def standardize_spect(spect, mean_freqs, std_freqs, non_zero_std):
     spect : numpy.ndarray
         with shape (frequencies, time bins)
     mean_freqs : numpy.ndarray
-        vector of mean values for each frequency bin across the fit set of spectrograms
+        vector of mean values for each row across the fit set of spectrograms
     std_freqs : numpy.ndarray
-        vector of standard deviations for each frequency bin across the fit set of spectrograms
+        vector of standard deviations for each row across the fit set of spectrograms
     non_zero_std : numpy.ndarray
         boolean, indicates where std_freqs has non-zero values. Used to avoid divide-by-zero errors.
 
@@ -32,13 +37,20 @@ def standardize_spect(spect, mean_freqs, std_freqs, non_zero_std):
     """
     tfm = spect - mean_freqs[:, np.newaxis]  # need axis for broadcasting
     # keep any stds that are zero from causing NaNs
-    tfm[non_zero_std, :] = tfm[non_zero_std, :] / std_freqs[non_zero_std, np.newaxis]
+    tfm[non_zero_std, :] = (
+        tfm[non_zero_std, :] / std_freqs[non_zero_std, np.newaxis]
+    )
     return tfm
 
 
-def pad_to_window(arr, window_size, padval=0.0, return_padding_mask=True):
-    """pad a 1d or 2d array so that it can be reshaped
-    into consecutive windows of specified size
+def pad_to_window(
+    arr: npt.NDArray,
+    window_size: int,
+    padval: float = 0.0,
+    return_padding_mask: bool = True,
+) -> npt.NDArray:
+    """Pad a 1d or 2d array so that it can be reshaped
+    into consecutive windows of specified size.
 
     Parameters
     ----------
@@ -61,13 +73,14 @@ def pad_to_window(arr, window_size, padval=0.0, return_padding_mask=True):
     Returns
     -------
     padded : numpy.ndarray
-        padded with padval
-    padding_mask : np.bool
-        has size equal to width of padded, i.e. original size
-        plus padding at the end. Has values of 1 where
-        columns in padded are from the original array,
-        and values of 0 where columns were added for padding.
-        Only returned if return_padding_mask is True.
+        Padded with ``padval``
+    padding_mask : numpy.ndarray
+        Boolean vector with size equal to width of padded,
+        i.e. original size plus padding at the end.
+        Has values of ``True`` where columns in ``padded``
+        are from the original array, and values of ``False``
+        where columns were added for padding.
+        Only returned if ``return_padding_mask`` is ``True``.
     """
     if arr.ndim == 1:
         width = arr.shape[0]
@@ -88,14 +101,14 @@ def pad_to_window(arr, window_size, padval=0.0, return_padding_mask=True):
         padded[:, :width] = arr
 
     if return_padding_mask:
-        padding_mask = np.zeros((target_width,), dtype=np.bool)
+        padding_mask = np.zeros((target_width,), dtype=bool)
         padding_mask[:width] = True
         return padded, padding_mask
     else:
         return padded
 
 
-def view_as_window_batch(arr, window_width):
+def view_as_window_batch(arr: npt.NDArray, window_size: int) -> npt.NDArray:
     """return view of a 1d or 2d array as a batch of non-overlapping windows
 
     Parameters
@@ -105,7 +118,7 @@ def view_as_window_batch(arr, window_width):
         or a 2-d array representing a spectrogram.
         If the array has 2-d dimensions, the returned array will
         have dimensions (batch, height of array, window width)
-    window_width : int
+    window_size : int
         width of window in number of elements.
 
     Returns
@@ -113,7 +126,7 @@ def view_as_window_batch(arr, window_width):
     batch_windows : numpy.ndarray
         with shape (batch size, window_size) if array is 1d,
         or with shape (batch size, height, window_size) if array is 2d.
-        Batch size will be arr.shape[-1] // window_width.
+        Batch size will be arr.shape[-1] // window_size.
         Window width must divide arr.shape[-1] evenly.
         To pad the array so it can be divided into windows of the specified
         width, use the `pad_to_window` transform
@@ -123,14 +136,16 @@ def view_as_window_batch(arr, window_width):
     adapted from skimage.util.view_as_blocks
     https://github.com/scikit-image/scikit-image/blob/f1b7cf60fb80822849129cb76269b75b8ef18db1/skimage/util/shape.py#L9
     """
-    if not (type(window_width) == int and window_width > 0):
-        raise ValueError(f"window width must be a positive integer")
+    if not isinstance(window_size, int) or window_size < 1:
+        raise ValueError(
+            f"`window_size` must be a positive integer, but was: {window_size}"
+        )
 
     if arr.ndim == 1:
-        window_shape = (window_width,)
+        window_shape = (window_size,)
     elif arr.ndim == 2:
         height, _ = arr.shape
-        window_shape = (height, window_width)
+        window_shape = (height, window_size)
     else:
         raise ValueError(
             f"input array must be 1d or 2d but number of dimensions was: {arr.ndim}"
@@ -140,7 +155,7 @@ def view_as_window_batch(arr, window_width):
     arr_shape = np.array(arr.shape)
     if (arr_shape % window_shape).sum() != 0:
         raise ValueError(
-            "'window_width' does not divide evenly into with 'arr' shape. "
+            "'window_size' does not divide evenly into with 'arr' shape. "
             "Use 'pad_to_window' transform to pad array so it can be windowed."
         )
 
@@ -149,10 +164,14 @@ def view_as_window_batch(arr, window_width):
     batch_windows = np.lib.stride_tricks.as_strided(
         arr, shape=new_shape, strides=new_strides
     )
-    # when 2d, first dim 1 because new shape has height equal to original arr
-    if batch_windows.ndim == 4 and batch_windows.shape[0] == 1:
-        # we don't want that extra dim of size 1, we want first dim to be "batch"
-        batch_windows = np.squeeze(batch_windows)
+
+    if (
+        arr.ndim == 2
+    ):  # avoids bug in vak version of transform, by not doing this to 1-D arrays
+        # TODO: figure out if there's a better way to do this where we don't need to squeeze
+        # The current version always add an initial dim of size 1
+        batch_windows = np.squeeze(batch_windows, axis=0)
+        # By squeezing just that first axis, we always end up with (batch, freq. bins, time bins) for a spectrogram
     return batch_windows
 
 
@@ -187,7 +206,8 @@ def to_longtensor(arr):
 
 
 def add_channel(input, channel_dim=0):
-    """add a channel dimension to a tensor.
+    """Add a "channel" dimension to a tensor.
+
     Transform that makes it easy to treat a spectrogram as an image,
     by adding a dimension with a single 'channel', analogous to grayscale.
     In this way the tensor can be fed to e.g. convolutional layers.
