@@ -1,14 +1,18 @@
+from __future__ import annotations
+
+import pathlib
+
 import numpy as np
+import pandas as pd
 
-from .. import files
-from ..validators import column_or_1d
-
+from ..common import constants
+from ..common.validators import column_or_1d
 from . import functional as F
 
 __all__ = [
     "AddChannel",
     "PadToWindow",
-    "StandardizeSpect",
+    "FramesStandardizer",
     "ToFloatTensor",
     "ToLongTensor",
     "ViewAsWindowBatch",
@@ -17,7 +21,7 @@ __all__ = [
 
 # adapted from:
 # https://github.com/NickleDave/hybrid-vocal-classifier/blob/master/hvc/neuralnet/utils.py
-class StandardizeSpect:
+class FramesStandardizer:
     """transform that standardizes spectrograms so they are all
     on the same scale, by subtracting off the mean and dividing by the
     standard deviation from a 'fit' set of spectrograms.
@@ -25,9 +29,9 @@ class StandardizeSpect:
     Attributes
     ----------
     mean_freqs : numpy.ndarray
-        mean values for each frequency bin across the fit set of spectrograms
+        mean values for each row across the fit set of spectrograms
     std_freqs : numpy.ndarray
-        standard deviation for each frequency bin across the fit set of spectrograms
+        standard deviation for each row across the fit set of spectrograms
     non_zero_std : numpy.ndarray
         boolean, indicates where std_freqs has non-zero values. Used to avoid divide-by-zero errors.
     """
@@ -38,26 +42,34 @@ class StandardizeSpect:
         Parameters
         ----------
         mean_freqs : numpy.ndarray
-            vector of mean values for each frequency bin across the fit set of spectrograms
+            vector of mean values for each row across the fit set of spectrograms
         std_freqs : numpy.ndarray
-            vector of standard deviations for each frequency bin across the fit set of spectrograms
+            vector of standard deviations for each row across the fit set of spectrograms
         non_zero_std : numpy.ndarray
             boolean, indicates where std_freqs has non-zero values. Used to avoid divide-by-zero errors.
         """
-        if any([arg is not None for arg in (mean_freqs, std_freqs, non_zero_std)]):
+        if any(
+            [arg is not None for arg in (mean_freqs, std_freqs, non_zero_std)]
+        ):
             mean_freqs, std_freqs, non_zero_std = (
-                column_or_1d(arr) for arr in (mean_freqs, std_freqs, non_zero_std)
+                column_or_1d(arr)
+                for arr in (mean_freqs, std_freqs, non_zero_std)
             )
             if (
                 len(
                     np.unique(
-                        [arg.shape[0] for arg in (mean_freqs, std_freqs, non_zero_std)]
+                        [
+                            arg.shape[0]
+                            for arg in (mean_freqs, std_freqs, non_zero_std)
+                        ]
                     )
                 )
                 != 1
             ):
                 raise ValueError(
-                    f"mean_freqs, std_freqs, and non_zero_std must all have the same length"
+                    "`mean_freqs`, `std_freqs`, and `non_zero_std` must all have the same length.\n"
+                    f"`mean_freqs.shape`: {mean_freqs.shape}, `std_freqs.shape`: {std_freqs.shape}, "
+                    f"`non_zero_std.shape`: {non_zero_std.shape}"
                 )
 
         self.mean_freqs = mean_freqs
@@ -65,41 +77,92 @@ class StandardizeSpect:
         self.non_zero_std = non_zero_std
 
     @classmethod
-    def fit_df(cls, df, spect_key="s"):
-        """fits StandardizeSpect instance, given a pandas DataFrame representing a dataset
+    def fit_inputs_targets_csv_path(
+        cls,
+        inputs_targets_csv_path: str | pathlib.Path,
+        dataset_path: str | pathlib.Path,
+        split: str = "train",
+        subset: str | None = None,
+        frames_path_col_name: str | None = None,
+        frames_key: str | None = None,
+    ):
+        if frames_path_col_name is None:
+            from .. import datapipes
 
-        Parameters
-        ----------
-        df : pandas.DataFrame
-            loaded from a .csv file representing a dataset, created by vak.io.dataframe.from_files
-        spect_key : str
-            key in files in 'spect_path' column that maps to spectrograms in arrays.
-            Default is 's'.
+            frames_path_col_name = (
+                datapipes.frame_classification.constants.FRAMES_PATH_COL_NAME
+            )
+        if frames_key is None:
+            frames_key = constants.SPECT_KEY
 
-        Returns
-        -------
-        standardize_spect : StandardizeSpect
-            instance fit to spectrograms in df
-        """
-        spect_paths = df["spect_path"]
-        spect = files.spect.load(spect_paths[0])[spect_key]
-        # in files, spectrograms are in orientation (freq bins, time bins)
+        inputs_targets_csv_path = pathlib.Path(inputs_targets_csv_path)
+        if not inputs_targets_csv_path.exists():
+            raise FileNotFoundError(
+                f"`inputs_targets_csv_path` for dataset not found: {inputs_targets_csv_path}"
+            )
+
+        dataset_path = pathlib.Path(dataset_path)
+        if not dataset_path.exists() or not dataset_path.is_dir():
+            raise NotADirectoryError(
+                f"`dataset_path` not found, or not a directory: {dataset_path}"
+            )
+
+        df = pd.read_csv(inputs_targets_csv_path)
+        if subset:
+            df = df[df.split == split].copy()
+        else:
+            df = df[df.split == split].copy()
+        frames_paths = df[frames_path_col_name].values
+        frames = np.load(dataset_path / frames_paths[0])[frames_key]
+
+        # in spectrograms files, spectrograms are in orientation (freq bins, time bins)
         # so we take mean and std across columns, i.e. time bins, i.e. axis 1
-        mean_freqs = np.mean(spect, axis=1)
-        std_freqs = np.std(spect, axis=1)
+        mean_freqs = np.mean(frames, axis=1)
+        std_freqs = np.std(frames, axis=1)
 
-        for spect_path in spect_paths[1:]:
-            spect = files.spect.load(spect_path)[spect_key]
-            mean_freqs += np.mean(spect, axis=1)
-            std_freqs += np.std(spect, axis=1)
-        mean_freqs = mean_freqs / len(spect_paths)
-        std_freqs = std_freqs / len(spect_paths)
+        for frames_path in frames_paths[1:]:
+            frames = np.load(dataset_path / frames_path)[frames_key]
+            mean_freqs += np.mean(frames, axis=1)
+            std_freqs += np.std(frames, axis=1)
+        mean_freqs = mean_freqs / len(frames_paths)
+        std_freqs = std_freqs / len(frames_paths)
         non_zero_std = np.argwhere(std_freqs != 0)
         return cls(mean_freqs, std_freqs, non_zero_std)
 
+    @classmethod
+    def fit_dataset_path(
+        cls, dataset_path, split="train", subset: str | None = None
+    ):
+        """Returns a :class:`StandardizeSpect` instance
+        that is fit to a split from a dataset,
+        given the path to that dataset and the
+        name of the split.
+
+        Parameters
+        ----------
+        dataset_path : str or pathlib.Path
+            Path to a dataset.
+        split : str
+            Name of split from dataset to fit.
+
+        Returns
+        -------
+        standardize_spect : StandardizeSpect
+            Instance that has been fit to input data from split.
+        """
+        from vak.datapipes.frame_classification import Metadata
+
+        dataset_path = pathlib.Path(dataset_path)
+        metadata = Metadata.from_dataset_path(dataset_path)
+        dataset_csv_path = dataset_path / metadata.dataset_csv_filename
+        dataset_path = dataset_csv_path.parent
+        return cls.fit_inputs_targets_csv_path(
+            dataset_csv_path, dataset_path, split, subset
+        )
+
     @classmethod
     def fit(cls, spect):
-        """fit a StandardizeSpect instance.
+        """Fit a StandardizeSpect instance.
 
         Parameters
         ----------
@@ -109,7 +172,7 @@ class StandardizeSpect:
         Notes
         -----
         Input should be spectrogram.
-        Fit function finds the mean and standard deviation of each frequency bin,
+        Fit function finds the mean and standard deviation of each row,
         which are used by `transform` method to scale other spectrograms.
         """
         # TODO: make this function accept list and/or ndarray with batch dimension
@@ -118,8 +181,6 @@ class StandardizeSpect:
 
         mean_freqs = np.mean(spect, axis=1)
         std_freqs = np.std(spect, axis=1)
-        assert mean_freqs.shape[-1] == spect.shape[0]
-        assert std_freqs.shape[-1] == spect.shape[0]
         non_zero_std = np.argwhere(std_freqs != 0)
         return cls(mean_freqs, std_freqs, non_zero_std)
 
@@ -135,17 +196,19 @@ class StandardizeSpect:
         -------
         z_norm_spect : numpy.ndarray
             array standardized to same scale as set of spectrograms that
-            SpectScaler was fit with
+            :class:`vak.transforms.FramesStandardizer` was fit with
         """
-        if any([not hasattr(self, attr) for attr in ["mean_freqs", "std_freqs"]]):
+        if any(
+            [not hasattr(self, attr) for attr in ["mean_freqs", "std_freqs"]]
+        ):
             raise AttributeError(
-                "SpectScaler properties are set to None,"
+                "FramesStandardizer properties are set to None,"
                 "must call fit method first to set the"
                 "value of these properties before calling"
                 "transform"
             )
 
-        if type(spect) != np.ndarray:
+        if not isinstance(spect, np.ndarray):
             raise TypeError(
                 f"type of spect must be numpy.ndarray but was: {type(spect)}"
             )
@@ -202,8 +265,9 @@ class PadToWindow:
     """
 
     def __init__(self, window_size, padval=0.0, return_padding_mask=True):
-        if not (type(window_size) == int) or (
-            type(window_size) == float and window_size.is_integer() is False
+        if not isinstance(window_size, int) or (
+            isinstance(window_size, float)
+            and window_size.is_integer() is False
         ):
             raise ValueError(
                 f"window size must be an int or a whole number float;"
@@ -214,7 +278,7 @@ class PadToWindow:
             raise TypeError(
                 f"type for padval must be int or float but was: {type(padval)}"
             )
-        if not type(return_padding_mask) == bool:
+        if not isinstance(return_padding_mask, bool):
             raise TypeError(
                 "return_padding_mask must be boolean (True or False), "
                 f"but was type {type(return_padding_mask)} with value {return_padding_mask}"
@@ -263,9 +327,10 @@ class ViewAsWindowBatch:
     https://github.com/scikit-image/scikit-image/blob/f1b7cf60fb80822849129cb76269b75b8ef18db1/skimage/util/shape.py#L9
     """
 
-    def __init__(self, window_width):
-        if not (type(window_width) == int) or (
-            type(window_width) == float and window_width.is_integer() is False
+    def __init__(self, window_width: int | float):
+        if not isinstance(window_width, int) or (
+            isinstance(window_width, float)
+            and window_width.is_integer() is False
         ):
             raise ValueError(
                 f"window size must be an int or a whole number float;"
@@ -329,7 +394,8 @@ class ToLongTensor:
 
 
 class AddChannel:
-    """add a channel dimension to a 2-dimensional tensor.
+    """Add a "channel" dimension to a tensor.
+
     Transform that makes it easy to treat a spectrogram as an image,
     by adding a dimension with a single 'channel', analogous to grayscale.
     In this way the tensor can be fed to e.g. convolutional layers.
@@ -343,9 +409,10 @@ class AddChannel:
         Default is 0, which returns a tensor with dimensions (channel, height, width).
     """
 
-    def __init__(self, channel_dim=0):
-        if not (type(channel_dim) == int) or (
-            type(channel_dim) == float and channel_dim.is_integer() is False
+    def __init__(self, channel_dim: int | float = 0):
+        if not isinstance(channel_dim, int) or (
+            isinstance(channel_dim, float)
+            and channel_dim.is_integer() is False
         ):
             raise ValueError(
                 f"window size must be an int or a whole number float;"
