@@ -1,4 +1,4 @@
-from . import test_parse
+from . import test_load
 from . import test_predict
 from . import test_prep
 from . import test_spect_params
