@@ -17,7 +17,7 @@ def test_onehot():
     # convert labels to one hot tensor
     one_hot = F.one_hot(labels, num_classes)
 
-    assert pytest.approx(one_hot[0, labels[0, 0, 0], 0, 0].item(), 1.0)
-    assert pytest.approx(one_hot[0, labels[0, 1, 0], 1, 0].item(), 1.0)
-    assert pytest.approx(one_hot[1, labels[1, 0, 0], 0, 0].item(), 1.0)
-    assert pytest.approx(one_hot[1, labels[1, 1, 0], 1, 0].item(), 1.0)
+    assert 1.0 == pytest.approx(one_hot[0, labels[0, 0, 0], 0, 0].item())
+    assert 1.0 == pytest.approx(one_hot[0, labels[0, 1, 0], 1, 0].item())
+    assert 1.0 == pytest.approx(one_hot[1, labels[1, 0, 0], 0, 0].item())
+    assert 1.0 == pytest.approx(one_hot[1, labels[1, 1, 0], 1, 0].item())
